@@ -28,6 +28,7 @@ sub login{
 
     my $ret = $self->_login();
     if($self->login_state eq "success"){
+        $self->clean_qrcode();
         $self->model_init();
         $self->emit("login"=>($ret==2?1:0));
     }
@@ -40,6 +41,14 @@ sub relogin{
     my $self = shift;
     my $retcode = shift;
     $self->info("正在重新登录...\n");
+    if(defined $self->_synccheck_connection_id){
+        eval{
+            $self->ioloop->remove($self->_synccheck_connection_id);
+            $self->_synccheck_running(0);
+            $self->info("停止接收消息...");
+        };
+        $self->info("停止接收消息失败: $@") if $@;
+    }
     $self->logout($retcode);
     $self->login_state("relogin");
     $self->ua->cookie_jar->empty;
@@ -57,6 +66,9 @@ sub relogin{
     $self->data(+{});
 
     $self->login();
+    $self->info("重新开始接收消息...");
+    $self->_synccheck();
+    $self->emit("relogin");
 }
 sub logout{
     my $self = shift;
